# Copyright (c) 2012 Ron McDowell
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# $Id$

f_get_member_groups() {
  pw_member_groups="$(
    echo $(
      sed 's/$/,/' /etc/group |grep "[:,]${1},"|cut -d':' -f1
    )
  )"
}

f_input_member_groups() {
  local varset=""
  while [ "$varset" = "" ]
  do
    dialog --backtitle "$backtitle" --title "$title" \
      --inputbox "Member of Groups" 0 0 "$old_pw_member_groups" 2> $BSDCFG_TMPF
    retval=$?
    pw_member_groups="$(cat $BSDCFG_TMPF)"
    rm $BSDCFG_TMPF
    varset="y"
    if [ $retval -eq 0 ]
    then
      if [ "$pw_member_groups" != "" ]
      then
        for grp in $pw_member_groups
        do
          if [ "$(grep "^$grp:" /etc/group 2>/dev/null)" = "" ]
          then
            f_show_msg "$grp: $msg_group_not_found"
            varset=""
          fi
        done
      fi
    fi
  done
  write_flag="y"
  f_dprintf "pw_member_groups: [$old_pw_member_groups]->[$pw_member_groups]"
}

f_input_name() {
  upper="ABCDEFGHIJKLMNOPQRSTUVWXYZ"
  lower="abcdefghijklmnopqrstuvwxyz"
  number="0123456789"
  nameset=""
  while [ "$nameset" = "" ]
  do
    dialog --backtitle "$backtitle" --title "$title" \
      --inputbox "Login" 0 0 "$old_pw_name" 2> $BSDCFG_TMPF
    retval=$?
    pw_name="$(cat $BSDCFG_TMPF)"
    rm $BSDCFG_TMPF
    nameset="y"
    if [ $retval -eq 0 ]
    then
      if [ "$pw_name" = "" ]
      then
        f_show_msg "$msg_login_is_empty"
        nameset=""
      else
        ch="`echo $pw_name|cut -c1`"
        if [ "`echo $upper$lower|grep $ch`" = "" ]
        then
          f_show_msg "$msg_login_must_start_with_letter"
          nameset=""
        else
          if [ "`grep "^$pw_name" /etc/master.passwd 2>/dev/null`" != "" ]
          then
            f_show_msg "$pw_name: $msg_login_already_used"
            nameset=""
          fi
        fi
      fi
    fi
  done
  write_flag="y"
  f_dprintf "pw_name: [$old_pw_name]->[$pw_name]"
}

f_input_password() {
  pwset=""
  while [ "$pwset" = "" ]
  do
    dialog --backtitle "$backtitle" --title "$title" \
      --insecure --passwordbox "Enter Password" 0 0 2> $BSDCFG_TMPF
    retval=$?
    pw_password1="$(cat $BSDCFG_TMPF)"
    rm $BSDCFG_TMPF
    if [ $retval -eq 0 ]
    then
      dialog --backtitle "$backtitle" --title "$title" \
        --insecure --passwordbox "Please Re-enter Password" 0 0 2> $BSDCFG_TMPF
      retval=$?
      pw_password2="$(cat $BSDCFG_TMPF)"
      rm $BSDCFG_TMPF
      if [ $retval -eq 0 ]
      then
        if [ "$pw_password1" = "" -o "$pw_password2" = "" ]
        then
          f_show_msg "$msg_password_is_empty"
        else
          if [ "$pw_password1" = "$pw_password2" ]
          then
            pwset="y"
            pw_password="$pw_password1"
          else 
            f_show_msg "$msg_passwords_do_not_match"
          fi
        fi
      else
        pwset="n"
      fi
    else
      pwset="n"
    fi
  done
  write_flag="y"
  f_dprintf "pw_password: [$old_pw_password]->[$pw_password]"
}

f_input_gecos() {
  dialog --backtitle "$backtitle" --title "$title" \
    --inputbox "Full Name" 0 0 "$old_pw_gecos" 2> $BSDCFG_TMPF
  retval=$?
  pw_gecos="$(cat $BSDCFG_TMPF)"
  rm $BSDCFG_TMPF
  write_flag="y"
  f_dprintf "pw_gecos: [$old_pw_gecos]->[$pw_gecos]"
}

f_input_uid() {
  dialog --backtitle "$backtitle" --title "$title" \
    --inputbox "UID" 0 0 "$old_pw_uid" 2> $BSDCFG_TMPF
  retval=$?
  pw_uid="$(cat $BSDCFG_TMPF)"
  rm $BSDCFG_TMPF
  write_flag="y"
  f_dprintf "pw_uid: [$old_pw_uid]->[$pw_uid]"
}

f_input_gid() {
  dialog --backtitle "$backtitle" --title "$title" \
    --inputbox "GID" 0 0 "$old_pw_gid" 2> $BSDCFG_TMPF
  retval=$?
  pw_gid="$(cat $BSDCFG_TMPF)"
  rm $BSDCFG_TMPF
  write_flag="y"
  f_dprintf "pw_gid: [$old_pw_gid]->[$pw_gid]"
}

f_input_class() {
  dialog --backtitle "$backtitle" --title "$title" \
    --inputbox "Class" 0 0 "$old_pw_class" 2> $BSDCFG_TMPF
  retval=$?
  pw_class="$(cat $BSDCFG_TMPF)"
  rm $BSDCFG_TMPF
  write_flag="y"
  f_dprintf "pw_class: [$old_pw_class]->[$pw_class]"
}

f_input_change() {
  dialog --backtitle "$backtitle" --title "$title" \
    --inputbox "PW Changes on" 0 0 "$old_pw_change" 2> $BSDCFG_TMPF
  retval=$?
  pw_change="$(cat $BSDCFG_TMPF)"
  rm $BSDCFG_TMPF
  write_flag="y"
  f_dprintf "pw_change: [$old_pw_change]->[$pw_change]"
}

f_input_expire() {
  dialog --backtitle "$backtitle" --title "$title" \
    --inputbox "PW Expires on" 0 0 "$old_pw_expire" 2> $BSDCFG_TMPF
  retval=$?
  pw_expire="$(cat $BSDCFG_TMPF)"
  rm $BSDCFG_TMPF
  write_flag="y"
  f_dprintf "pw_expire: [$old_pw_expire]->[$pw_expire]"
}

f_input_home_dir() {
  dialog --backtitle "$backtitle" --title "$title" \
    --inputbox "Home" 0 0 "$old_pw_home_dir" 2> $BSDCFG_TMPF
  retval=$?
  pw_home_dir="$(cat $BSDCFG_TMPF)"
  rm $BSDCFG_TMPF
  write_flag="y"
  f_dprintf "pw_home_dir: [$old_pw_home_dir]->[$pw_home_dir]"
}

f_input_home_create() {
  dialog --backtitle "$backtitle" --title "$title" \
    --yesno "Create Home Directory?" 0 0
  retval=$?
  [ "$retval" -eq "0" ] && pw_home_create="Yes"
  [ "$retval" -eq "1" ] && pw_home_create="No"
  retval=0
  write_flag="y"
  f_dprintf "pw_home_create: [$old_pw_home_create]->[$pw_home_create]"
}

f_input_home_delete() {
  dialog --backtitle "$backtitle" --title "$title" \
    --yesno "Delete Home Directory?" 0 0
  retval=$?
  [ "$retval" -eq "0" ] && pw_home_delete="Yes"
  [ "$retval" -eq "1" ] && pw_home_delete="No"
  retval=0
  write_flag="y"
  f_dprintf "pw_home_delete: [$old_pw_home_delete]->[$pw_home_delete]"
}

f_input_dotfiles_create() {
  dialog --backtitle "$backtitle" --title "$title" \
    --yesno "Create Dotfiles in Home Directory?" 0 0
  retval=$?
  [ "$retval" -eq "0" ] && pw_dotfiles_create="Yes"
  [ "$retval" -eq "1" ] && pw_dotfiles_create="No"
  retval=0
  write_flag="y"
  f_dprintf "pw_dotfiles_create: [$old_pw_dotfiles_create]->[$pw_dotfiles_create]"
}

f_input_shell() {
  echo -n "dialog --backtitle \"$backtitle\" --title \"$title\" " >> $BSDCFG_TMPF.1
  echo -n "--radiolist \" \" 0 0 0 " >> $BSDCFG_TMPF.1
  for shell in `sed "s/#.*//" /etc/shells | grep -v "^$"`
  do
    echo -n "\"$shell\" \"\" " >> $BSDCFG_TMPF.1
    if [ "$old_pw_shell" = "$shell" ]
    then
      echo -n "on " >> $BSDCFG_TMPF.1
    else
      echo -n "off " >> $BSDCFG_TMPF.1
    fi
  done
  echo "" >> $BSDCFG_TMPF.1
  . $BSDCFG_TMPF.1 2> $BSDCFG_TMPF
  retval=$?
  rm $BSDCFG_TMPF.1
  pw_shell="$(cat $BSDCFG_TMPF)"
  rm $BSDCFG_TMPF
  write_flag="y"
  f_dprintf "pw_shell: [$old_pw_shell]->[$pw_shell]"
}

